@@ -3,8 +3,8 @@
 /*
    File:         depth.h
    Created by:   Rainer Dyckerhoff
-   Last revised: 15.11.1996
-   
+   Last revised: 15.05.2013
+
    Computation of the zonoid data depth. 
    
    For a description of the algorithm, see:
@@ -31,5 +31,9 @@ double ZonoidDepth(vector<TPoint> x, TPoint z, int& Error);
 int IsInConvex(vector<TPoint> x, TPoint z, int& Error);
 int InConvexes(TMatrix points, TVariables cardinalities, TMatrix objects, int& Error, TVariables *areInConvexes);
 
+int GetMeansSds(vector<TPoint> x, TPoint *means, TPoint *sds);
+int Standardize(vector<TPoint> &x, TPoint means, TPoint sds);
+int Standardize(TPoint &x, TPoint means, TPoint sds);
+
 #endif
 
